# LlamaIndex Postprocessor Integration: Colbert Rerank

[Colbert](https://github.com/stanford-futuredata/ColBERT): ColBERT is a fast and accurate retrieval model, enabling scalable BERT-based search over large text collections in tens of milliseconds.

Please `pip install llama-index-postprocessor-colbert-rerank` to install Colbert Rerank package.
